#!/usr/bin/env gnuplot

reset

set terminal pdfcairo enhanced color size 8.3 cm, 10.3 cm font ",10"
set multiplot layout 2,1

rswidth = 1

set lmargin 9.0
set bmargin 3.5
set rmargin 2.0
set tmargin 2.0

labelx = 0.05
set label "a" at screen labelx,0.98 font "{:Bold},12"
set label "b" at screen labelx,0.48 font "{:Bold},12"

# https://sodocumentation.net/gnuplot/topic/8825/fit-data-with-gnuplot
#f(x) = a * exp(b * x)
f(x, v) = a * x**b * v
fit f(x, 100) "sediment_flux_v3.169e-6ms.txt" u ($1/1000):($2*3600*24*365.25*rswidth) via a,b
fitparams = sprintf("{/:Italic q}_t = %.2e {/:Italic v N'}^{%.3g}", a, b)

set xlabel "Effective stress, {/:Italic N'} [kPa]"
set ylabel "Sediment flux, {/:Italic q}_t [m²/a]"
set key bottom right font ",09" invert samplen 1.0 box lw 0.5
#set title "{/:Italic v} = 100 m/a"
set xrange [0:210]
set xtics 0,50,200

set title "{/:Italic v} = 100 m/a"
set yrange [0:1.1]
plot f(x, 100) lt 1 t fitparams, \
	"sediment_flux_v3.169e-6ms.txt" u ($1/1000):($2*3600*24*365.25*rswidth) w p lt 2 ps 0.5 t "CNGF-PF (Damsgaard et al., 2020)", \
	"rs_sediment_flux_100ma_high-N.txt" u ($1/1000):($2) w p lt 4 ps 1 t "Hansen and Zoet (2022)", \
	"rs_sediment_flux_100ma.txt" u ($1/1000):($2) w p lt 4 ps 1 t ""

set title "{/:Italic v} = 300 m/a"
set yrange [0:*]
plot f(x, 300) lt 1 t fitparams, \
	"sediment_flux_v9.506e-6ms.txt" u ($1/1000):($2*3600*24*365.25*rswidth) w p lt 2 ps 0.5 t "CNGF-PF (Damsgaard et al., 2020)", \
	"rs_sediment_flux_300ma.txt" u ($1/1000):($2) w p lt 4 ps 1 t "Hansen and Zoet (2022)"
