#!/usr/bin/env gnuplot

set terminal pdfcairo color size 8.3 cm, 17 cm font ",10"

set multiplot layout 3,1

f_min = 1e-9
f_max = 1e-3
D_min = 1e-9
D_max = 1e-3

label_y = 3*D_min
x=1.0/3600.0
set arrow from x,D_min to x,D_max nohead lc "white" front
set label "hourly" at x,label_y rotate by 90 front offset screen -0.01,0 textcolor "white"
x=1.0/3600.0/24.0
set arrow from x,D_min to x,D_max nohead lc "white" front
set label "daily" at x,label_y rotate by 90 front offset screen -0.01,0 textcolor "white"
x=1.0/3600.0/24.0/30.0
set arrow from x,D_min to x,D_max nohead lc "white" front
set label "monthly" at x,label_y rotate by 90 front offset screen -0.01,0 textcolor "white"
x=1.0/3600.0/24.0/365.0
set arrow from x,D_min to x,D_max nohead lc "white" front
set label "yearly" at x,label_y rotate by 90 front offset screen -0.01,0 textcolor "white"

set border 31 lc rgbcolor "#666666"

set label "a" at screen 0.01,0.99 font "{:Bold},12"
set label "b" at screen 0.01,0.66 font "{:Bold},12"
set label "c" at screen 0.01,0.33 font "{:Bold},12"

set xlabel "Forcing frequency, {/:Italic f} [s^{-1}]"
set ylabel "Diffusivity, {/:Italic D} [m^2/s]"
set cblabel "Max. deformation depth, {/:Italic z'} [m]"

set xrange [f_min:f_max]
set yrange [D_min:D_max]
set xtics rotate by 90
set ytics offset 1
set format x '10^{%T}'
set format y '10^{%T}'

set view map scale 1
set style data pm3d
set style function pm3d
set xyplane relative 0
set nomcbtics
set pm3d implicit at b
set pm3d scansforward
#set pm3d interpolate 10,10
set logscale xy

set title "{/:Italic A}_f = 1 kPa"
splot 'max_depth_ampl1e3.txt' notitle with lines palette, \
      '' with pm3d notitle

set title "{/:Italic A}_f = 10 kPa"
splot 'max_depth_ampl10e3.txt' notitle with lines palette, \
      '' with pm3d notitle

set title "{/:Italic A}_f = 100 kPa"
splot 'max_depth_ampl100e3.txt' notitle with lines palette, \
      '' with pm3d notitle
